pub struct LibertyAst(pub Vec<GroupItem>);Expand description
Liberty file AST representation
Each liberty file can have one or more librarys defined in it, which are represented as a
GroupItem::Group variant.
Tuple Fields
0: Vec<GroupItem>Implementations
Sourceimpl LibertyAst
impl LibertyAst
Sourcepub fn from_string(input: &str) -> ParseResult<'_, Self>
pub fn from_string(input: &str) -> ParseResult<'_, Self>
Parse a Liberty file’s string representation into the AST
Sourcepub fn into_liberty(self) -> Liberty
pub fn into_liberty(self) -> Liberty
Convert an AST into a Liberty struct
Sourcepub fn from_liberty(lib: Liberty) -> Self
pub fn from_liberty(lib: Liberty) -> Self
Convert a Liberty struct into an AST